
local Object = require("classic")
local Button = Object:extend()

local function boxCollision(a, b)
return a.x < b.x + b.width and a.x + a.width > b.x and
  a.y < b.y + b.height and a.y + a.height > b.y
end


function Button:new(name, x, y, onClick)
  self.name = name or "Button"
  self.width = 96
  self.height = 16
  self.x = x
  self.y = y
  self.onClick = onClick or function() print("Button '"..self.name.."' is missing an 'onClick' event!") end
  self.mouseHover = false
  self.removed = false
end


function Button:destroy()
  self.removed = true
end


function Button:update(dt)
  self.mouseHover = false
  if boxCollision({x=love.mouse.getX(), y=love.mouse.getY(), width=1, height=1}, self) then
    self.mouseHover = true
  end
end


function Button:draw()
  if self.mouseHover then love.graphics.setColor(255, 0, 0)
  else love.graphics.setColor(255, 255, 255) end
  love.graphics.rectangle("line", self.x, self.y, self.width, self.height)
  love.graphics.printf(self.name, self.x, self.y+2, self.width, "center")
  love.graphics.setColor(255, 255, 255)
end


function Button:mousepressed(x, y, button)
  if self.mouseHover and button == 1 then self:onClick() end
end

return Button

